@@ -26,7 +26,7 @@ def login(api, args):
     while 1:
         print
         print "How do you want to authenticate?"
-        print "1. Enter the 32-digit API key (valid until deactivated)"
+        print "1. Enter the %d-character API key (valid until deactivated)" % KEYLEN
         print "2. Enter your username/password (temporary login)"
         print "3. Enter a long code (visible on the API key page)"
         print "q. Quit"
@@ -49,6 +49,7 @@ def login(api, args):
             key = raw_input("API KEY: ")
             if len(key) != KEYLEN:
                 print "An API key is exactly %d characters long" % KEYLEN
+                print "If you lost your secret key part, you must rekey your key."
             else:
                 break
     elif s == '2':
